"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const abstract_command_1 = require("./abstract-command");
const shell_1 = require("../utils/shell");
const file_operations_1 = require("../utils/file-operations");
const path = require("path");
const logger_1 = require("../utils/logger");
class Deploy extends abstract_command_1.AbstractCommand {
    getName() {
        return 'deploy [project-path]';
    }
    getDescription() {
        return 'Deploy project to production';
    }
    getAlias() {
        return 'd';
    }
    getAction() {
        return (projectPath) => __awaiter(this, void 0, void 0, function* () {
            try {
                const pathToAppend = projectPath ? projectPath : '';
                const pkgJsonFile = path.join(pathToAppend, 'package.json');
                const pkgJsonFileExist = yield file_operations_1.fileExists(pkgJsonFile);
                if (!pkgJsonFileExist) {
                    logger_1.default.error('No package.json file found, exiting...');
                    return;
                }
                logger_1.default.info('Deploying server to production...');
                if (pathToAppend !== '') {
                    process.chdir(pathToAppend);
                }
                yield shell_1.shell(this.getDeployCommand());
                logger_1.default.info('Project successfully deployed!');
            }
            catch (err) {
                logger_1.default.error(`Got error in deploy command- ${err}`);
            }
        });
    }
    getDeployCommand() {
        return `npm run deploy`;
    }
}
exports.Deploy = Deploy;
//# sourceMappingURL=deploy.js.map