"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const abstract_command_1 = require("./abstract-command");
const inquirer = require("inquirer");
const shell_1 = require("../utils/shell");
const logger_1 = require("../utils/logger");
const questions = [
    {
        type: 'rawlist',
        name: 'seedName',
        message: 'Select seed type',
        choices: [
            {
                name: 'graphql-server-typed: Typescript server deployed on now',
                value: 'graphql-server-typed'
            },
            {
                name: 'apollo-typed-lambda: Typescript server for aws lambda deployment',
                value: 'apollo-typed-lambda'
            }
        ]
    }
];
class Init extends abstract_command_1.AbstractCommand {
    getName() {
        return 'init <name>';
    }
    getDescription() {
        return 'Create new project';
    }
    getAlias() {
        return 'i';
    }
    getAction() {
        return (projectName) => __awaiter(this, void 0, void 0, function* () {
            try {
                const answer = yield inquirer.prompt(questions);
                yield shell_1.shell(this.getCloneCommand(answer.seedName, projectName));
                logger_1.default.info('Project cloned, installing dependencies...');
                process.chdir(projectName);
                yield shell_1.shell(this.getInstallCommand());
                logger_1.default.info('Dependencies installed successfully');
            }
            catch (err) {
                logger_1.default.error(`Got error in init command- ${err}`);
            }
        });
    }
    getCloneCommand(seedName, projectName) {
        const seedUrlToClone = this.getSeedUrlToClone(seedName);
        return `git clone ${seedUrlToClone} ${projectName}`;
    }
    getSeedUrlToClone(seedName) {
        return `https://github.com/tomyitav/${seedName}.git`;
    }
    getInstallCommand() {
        return `npm install`;
    }
}
exports.Init = Init;
//# sourceMappingURL=init.js.map