"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const abstract_command_1 = require("../abstract-command");
const transform_ = require("graphql-json-schema");
const transform = transform_;
const resolver_constants_1 = require("./resolver-constants");
const file_operations_1 = require("../../utils/file-operations");
const logger_1 = require("../../utils/logger");
class Resolver extends abstract_command_1.AbstractCommand {
    getName() {
        return 'resolver <path-to-type> <path-to-resolver>';
    }
    getAction() {
        return (pathToType, pathToResolver) => __awaiter(this, void 0, void 0, function* () {
            try {
                const resolverExists = yield file_operations_1.fileExists(pathToResolver);
                if (resolverExists) {
                    logger_1.default.warn('Resolver file already exists. please select a different path or remove the current file...');
                    return;
                }
                const schema = yield this.getSchemaByFilePath(pathToType);
                if (!schema || schema === '') {
                    logger_1.default.error('Failed to read schema, exiting...');
                    return;
                }
                const schemaJsonRepresentation = transform(schema);
                const resolverContent = this.resolverContentByJsonSchema(schemaJsonRepresentation);
                logger_1.default.info('Writing resolvers to ' + pathToResolver + '...');
                yield file_operations_1.writeToFile(pathToResolver, resolverContent);
                logger_1.default.info('Resolver file was created successfully!');
            }
            catch (err) {
                logger_1.default.error(`Error in generating resolver- ${err}`);
            }
        });
    }
    getAlias() {
        return 'r';
    }
    getDescription() {
        return 'Generate new resolver by path to type file';
    }
    resolverContentByJsonSchema(jsonSchema) {
        const schemaDefinitions = jsonSchema.definitions;
        let resolverContent = resolver_constants_1.resolverPrefix;
        Object.entries(schemaDefinitions).forEach(([key, operation]) => {
            if (resolver_constants_1.keysToGenerate.includes(key)) {
                resolverContent += this.getTypeOperationContent(operation);
            }
        });
        resolverContent += resolver_constants_1.resolverSuffix;
        return resolverContent;
    }
    getTypeOperationContent(operation) {
        let opStrRepresentation = '\t' + operation.title + resolver_constants_1.operationPrefix;
        const operationProperties = operation.properties;
        Object.keys(operationProperties).forEach((key) => {
            opStrRepresentation += this.getTypeOperationParamContent(key, operation);
        });
        opStrRepresentation += resolver_constants_1.operationFuntionsSuffix;
        return opStrRepresentation;
    }
    getTypeOperationParamContent(key, operation) {
        let operationParamStr = '\t\t' + key;
        if (operation.title === 'Subscription') {
            operationParamStr +=
                resolver_constants_1.operationPrefix +
                    resolver_constants_1.subscriptionSubscribeDefinition +
                    resolver_constants_1.gqlMethodSignature +
                    resolver_constants_1.functionOperationPrefix +
                    '\t' +
                    resolver_constants_1.operationFuntionsSuffix;
        }
        else {
            operationParamStr += resolver_constants_1.gqlMethodSignature + resolver_constants_1.gqlMethodSuffix;
        }
        return operationParamStr;
    }
    getSchemaByFilePath(pathToType) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const typeFileContent = yield file_operations_1.readFileContent(pathToType);
                const splittedBySchema = typeFileContent.split('`');
                if (splittedBySchema.length !== 3) {
                    return '';
                }
                return splittedBySchema[1];
            }
            catch (err) {
                logger_1.default.error(`Got error in reading type file- ${err}`);
                return '';
            }
        });
    }
}
exports.Resolver = Resolver;
//# sourceMappingURL=resolver.js.map