"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const fse = require("fs-extra");
const find_ = require("find");
const find = find_;
const allowedFileExtensions = ['.ts'];
function writeToFile(pathToFile, content) {
    return new Promise((resolve, reject) => {
        const pathProps = path.parse(pathToFile);
        if (!allowedFileExtensions.includes(pathProps.ext)) {
            reject('Illegal file extension.. only ' + allowedFileExtensions + ' extensions are allowed');
            return;
        }
        return fse.ensureDir(pathProps.dir).then(() => {
            fs.writeFile(pathToFile, content, err => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve();
                }
            });
        });
    });
}
exports.writeToFile = writeToFile;
function fileExists(pathToFile) {
    return new Promise(resolve => {
        fs.stat(pathToFile, (err, stats) => {
            if (err) {
                resolve(false);
            }
            else {
                resolve(stats.isFile());
            }
        });
    });
}
exports.fileExists = fileExists;
function locateFile(pattern, rootPath, fileType) {
    const locatingFunction = fileType === 'file' ? find.file : find.dir;
    return new Promise((resolve, reject) => {
        if (!pattern) {
            reject('Illegal pattern received in locate function');
        }
        locatingFunction(pattern, rootPath, (results) => {
            resolve(results);
        }).error((err) => {
            if (err) {
                reject(err);
            }
        });
    });
}
exports.locateFile = locateFile;
function readFileContent(pathToFile) {
    return new Promise((resolve, reject) => {
        fs.readFile(pathToFile, (err, data) => {
            if (err) {
                reject(err);
            }
            else {
                resolve(data.toString());
            }
        });
    });
}
exports.readFileContent = readFileContent;
function findCommonPath(stringsToCheck) {
    if (Array.isArray(stringsToCheck) && stringsToCheck.length > 0) {
        if (stringsToCheck.length === 1) {
            return stringsToCheck[0];
        }
        const sortedArray = stringsToCheck.concat().sort();
        const first = sortedArray[0];
        const last = sortedArray[sortedArray.length - 1];
        const L = first.length;
        let i = 0;
        while (i < L && first.charAt(i) === last.charAt(i))
            i++;
        return first.substring(0, i);
    }
    else {
        return '';
    }
}
exports.findCommonPath = findCommonPath;
//# sourceMappingURL=file-operations.js.map